# CHANGELOG

## Unreleased

### Changed

- Remove `instructor` package.

## 0.1.0

### Added

- Created `GroundedQAEvaluator` that evaluates four metrics per sample: answer relevancy, completeness, faithfulness, usefulness, negative rejection and positive acceptance.
- Created `MetaEvaluator` to evaluate evaluators on GroUSE unit tests.
